@@ -1,5 +1,6 @@
 #!/usr/bin/env bash
-# Copyright (C) 2022 The Qt Company Ltd.
+
+# Copyright (C) 2023 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 set -ex
@@ -20,9 +21,7 @@ sudo timedatectl set-timezone Etc/UTC
 
 "$BASEDIR/../common/linux/configure-gnome-shell.sh"
 
-echo "Disable windows key from showing the GNOME Shell Activities overlay"
-gsettings set org.gnome.mutter overlay-key ""
-
 # Set Wayland enable as false.
 echo "Setting Wayland enable as false"
 sudo sed -i 's/#WaylandEnable=false/WaylandEnable=false/g' /etc/gdm/custom.conf
+
