@@ -1,5 +1,5 @@
 #!/usr/bin/env bash
-# Copyright (C) 2022 The Qt Company Ltd.
+# Copyright (C) 2025 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 # Install required packages with APT
@@ -19,18 +19,17 @@ function set_internal_repo {
     # Stop fetching the dep-11 metadata, since our mirrors do not handle them well
     sudo mv /etc/apt/apt.conf.d/50appstream{,.disabled}
 
-    sudo tee "/etc/apt/sources.list" > /dev/null <<-EOC
-    deb [arch=amd64] http://repo-clones.ci.qt.io/apt-mirror/mirror/ubuntu/ jammy main restricted universe multiverse
-    deb [arch=amd64] http://repo-clones.ci.qt.io/apt-mirror/mirror/ubuntu/ jammy-updates main restricted universe multiverse
-    deb [arch=amd64] http://repo-clones.ci.qt.io/apt-mirror/mirror/ubuntu/ jammy-backports main restricted universe
-    deb [arch=amd64] http://repo-clones.ci.qt.io/apt-mirror/mirror/ubuntu/ jammy-security main restricted universe multiverse
-    deb [arch=i386] http://repo-clones.ci.qt.io/apt-mirror/mirror/ubuntu/ jammy main restricted
-    deb [arch=i386] http://repo-clones.ci.qt.io/apt-mirror/mirror/ubuntu/ jammy-updates main restricted
-    deb [arch=i386] http://repo-clones.ci.qt.io/apt-mirror/mirror/ubuntu/ jammy universe
+    sudo tee "/etc/apt/sources.list.d/ubuntu.list" > /dev/null <<-EOC
+    deb [arch=amd64 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 noble-amd64 main restricted universe multiverse
+    deb [arch=amd64 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 noble-updates-amd64 main restricted universe multiverse
+    deb [arch=amd64 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 noble-backports-amd64 main restricted universe
+    deb [arch=amd64 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 noble-security-amd64 main restricted universe multiverse
+    deb [arch=i386 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 noble-i386 main restricted universe multiverse
+    deb [arch=i386 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 noble-updates-i386 main restricted universe multiverse
 EOC
 }
 
-(ping -c 3 repo-clones.ci.qt.io && set_internal_repo) || echo "Internal package repository not found. Using public repositories."
+(ping -c 3 repo-clones-apt.ci.qt.io && set_internal_repo) || echo "Internal package repository not found. Using public repositories."
 
 # Make sure needed ca-certificates are available
 sudo apt-get install --reinstall ca-certificates
@@ -113,6 +112,8 @@ installPackages+=(libva-dev)
 # for QtMultimedia streaming tests
 installPackages+=(vlc-bin)
 installPackages+=(vlc-plugin-base)
+# for tst_qfloat16format, see also QTQAINFRA-6390
+installPackages+=(locales-all)
 
 # Support for cross-building to x86 (needed by WebEngine boot2qt builds)
 installPackages+=(g++-multilib)
@@ -123,12 +124,18 @@ installPackages+=(python3-venv)
 installPackages+=(virtualenv)
 installPackages+=(python3-wheel)
 installPackages+=(python-is-python3)
+# TODO: Ubuntu 24.04 Removal - not available
 # python2 development package
-installPackages+=(python2-dev)
+#installPackages+=(python2-dev)
+
 # Automates interactive applications (Needed by RTA to automate configure testing)
 installPackages+=(expect)
 installPackages+=(mesa-common-dev)
-installPackages+=(libgl1-mesa-glx)
+
+# TODO: Ubuntu 24.04 Replacement
+#installPackages+=(libgl1-mesa-glx)
+installPackages+=(libglx-mesa0)
+
 installPackages+=(libgl1-mesa-dev)
 installPackages+=(libegl1-mesa-dev)
 installPackages+=(libegl1)
@@ -177,6 +184,7 @@ installPackages+=(virtualbox)
 installPackages+=(dkms)
 # Needed for qtspeech
 installPackages+=(libspeechd-dev)
+installPackages+=(flite1-dev)
 #Pypdf for PDF reading in RTA tests
 installPackages+=(python3-pypdf2)
 # Needed for b2qt
@@ -213,7 +221,9 @@ installPackages+=(libvulkan-dev)
 installPackages+=(libdlt-dev)
 # For integrity
 installPackages+=(libc6:i386)
-installPackages+=(libncurses5:i386)
+# TODO: Ubuntu 24.04 Removal - not available
+#installPackages+=(libncurses5:i386)
+
 installPackages+=(libstdc++6:i386)
 installPackages+=(libx11-6:i386)
 installPackages+=(lib32z1)
@@ -235,16 +245,9 @@ installPackages+=(cifs-utils)
 installPackages+=(uml-utilities)
 # used for reading vcpkg packages version, from vcpkg.json
 installPackages+=(jq)
-# To save iptables rules
-installPackages+=(iptables-persistent)
 
 installPackages+=(patchelf)
 
-# For Firebird in RTA
-installPackages+=(libtommath-dev)
-# For tst_license.pl with all the machines generating SBOM
-installPackages+=(libjson-perl)
-
 echo "Running update for apt"
 waitLoop
 sudo apt-get update
@@ -255,7 +258,9 @@ sudo DEBIAN_FRONTEND=noninteractive apt-get -q -y -o DPkg::Lock::Timeout=300 ins
 # Configure pip
 pip config --user set global.index https://ci-files01-hki.ci.qt.io/input/python_module_cache
 pip config --user set global.extra-index-url https://pypi.org/simple/
-pip install --user -r "${BASH_SOURCE%/*}/../common/shared/sbom_requirements.txt"
+# Ubuntu 24.04 comes with a newer pip that disallows installing into the system site-packages,
+# so we explicitly ask it to allow it.
+pip install --user -r "${BASH_SOURCE%/*}/../common/shared/sbom_requirements.txt" --break-system-packages
 
 source "${BASH_SOURCE%/*}/../common/unix/SetEnvVar.sh"
 # SetEnvVar "PATH" "/usr/lib/nodejs-mozilla/bin:\$PATH"
@@ -268,5 +273,8 @@ SetEnvVar "SBOM_PYTHON_APPS_PATH" "/home/qt/.local/bin"
 gccVersion="$(gcc --version |grep -Eo '[0-9]+\.[0-9]+(\.[0-9]+)?' |head -n 1)"
 echo "GCC = $gccVersion" >> versions.txt
 
+glibcVersion="$(ldd --version |grep -Eo '[0-9]+\.[0-9]+(\.[0-9]+)?' |head -n 1)"
+echo "glibc = $glibcVersion" >> versions.txt
+
 OpenSSLVersion="$(openssl version |cut -b 9-14)"
 echo "System's OpenSSL = $OpenSSLVersion" >> ~/versions.txt
