@@ -1,6 +1,5 @@
 #!/usr/bin/env bash
-# Copyright (C) 2022 The Qt Company Ltd.
-# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+# Copyright (C) 2024 The Qt Company Ltd.
 
 set -ex
 
@@ -10,6 +9,9 @@ sudo /usr/sbin/update-alternatives --install /usr/bin/gcc gcc /usr/bin/gcc-9 1 \
                                      --slave /usr/bin/cc cc /usr/bin/gcc-9 \
                                      --slave /usr/bin/c++ c++ /usr/bin/g++-9
 
+# Make sure needed ca-certificates are available
+sudo zypper -nq install ca-certificates
+
 sudo zypper -nq install bison flex gperf \
         zlib-devel \
         systemd-devel \
@@ -37,13 +39,11 @@ sudo zypper -nq install xcb-util-devel xcb-util-image-devel xcb-util-keysyms-dev
 sudo zypper -nq install libicu-devel
 
 # qtwebengine
+# Removing nodejs12 as it's not available and testing with common nodejs 18.16.0
 sudo zypper -nq install alsa-devel dbus-1-devel libxkbfile-devel \
          libXcomposite-devel libXcursor-devel libXrandr-devel libXtst-devel \
-         mozilla-nspr-devel mozilla-nss-devel nodejs12 glproto-devel \
-         libxshmfence-devel libXdamage-devel libdrm-devel libgbm-devel
-
-# qtwebengine, qtmultimedia+ffmpeg
-sudo zypper -nq install libva-devel
+         mozilla-nspr-devel mozilla-nss-devel glproto-devel \
+         libxshmfence-devel libXdamage-devel
 
 # qtwebkit
 sudo zypper -nq install libxml2-devel libxslt-devel
@@ -52,7 +52,7 @@ sudo zypper -nq install libxml2-devel libxslt-devel
 sudo zypper -nq install yasm
 
 # GStreamer (qtwebkit and qtmultimedia), pulseaudio (qtmultimedia)
-sudo zypper -nq install gstreamer-devel gstreamer-plugins-base-devel libpulse-devel
+sudo zypper -nq install gstreamer-devel gstreamer-plugins-base-devel libpulse-devel pipewire-devel gstreamer-plugin-openh264
 
 # cups
 sudo zypper -nq install cups-devel
@@ -66,17 +66,35 @@ sudo zypper -nq install make
 # Tools to build Git
 sudo zypper -nq install autoconf libcurl-devel libexpat-devel
 
+# zip, needed for vcpkg caching
+sudo zypper -nq install zip
+
 # OpenSSL 3
 sudo zypper -nq install openssl-3
 
+# used for reading vcpkg packages version, from vcpkg.json
+sudo zypper -nq install jq
+
 # Valgrind (Needed for testlib selftests)
 sudo zypper -nq install valgrind-devel
 
+# cifs-utils, for mounting smb drive
+sudo zypper -nq install cifs-utils
+
+# For Firebird in RTA
+sudo zypper -nq install libtommath-devel
+
 # Java
 sudo zypper -nq install java-17-openjdk
 
+# For tst_license.pl with all the machines generating SBOM
+sudo zypper -nq install perl-JSON
+
 gccVersion="$(gcc --version |grep -Eo '[0-9]+\.[0-9]+(\.[0-9]+)?' |head -n 1)"
 echo "GCC = $gccVersion" >> versions.txt
 
-OpenSSLVersion="$(openssl-3 version |cut -b 9-14)"
-echo "OpenSSL = $OpenSSLVersion" >> ~/versions.txt
+glibcVersion="$(ldd --version |grep -Eo '[0-9]+\.[0-9]+(\.[0-9]+)?' |head -n 1)"
+echo "glibc = $glibcVersion" >> versions.txt
+
+OpenSSLVersion="$(openssl version |cut -b 9-14)"
+echo "System's OpenSSL = $OpenSSLVersion" >> ~/versions.txt
